@@ -360,12 +360,14 @@ public class BasicInformationView extends Composite implements FormValidator {
 				listOfContributorsView = new ArrayList<CreatorsFormView>();
 
 			// ADDING AUTHORS
-			GWT.log("Adding creators: " + zenodoItem.getMetadata().getCreators());
-			CreatorsFormView authorView = new CreatorsFormView(zenodoItem.getMetadata().getCreators());
+			List<? extends ZenodoAuthor> authors = zenodoItem.getMetadata().getCreators();
+			GWT.log("Adding creators: " + authors);
+			CreatorsFormView authorView = new CreatorsFormView(authors, ZenodoCreator.class);
 			listOfCreatorsView.add(authorView);
 
-			GWT.log("Adding contributors: " + zenodoItem.getMetadata().getContributors());
-			CreatorsFormView contributorView = new CreatorsFormView(zenodoItem.getMetadata().getContributors());
+			List<? extends ZenodoAuthor> contributors = zenodoItem.getMetadata().getContributors();
+			GWT.log("Adding contributors: " + contributors);
+			CreatorsFormView contributorView = new CreatorsFormView(contributors, ZenodoContributor.class);
 			listOfContributorsView.add(contributorView);
 
 			for (CreatorsFormView cfv : listOfCreatorsView) {
